# Attendance Tracker #

Generates a dashboard to monitor student attendance across several subjects.

## How to use ##

### Installation ###
1. Create a new project with a virtual environment (Python 3.10).
2. Activate the virtual environment.
3. Install the package using: `pip install nicola-student-tracker`.

### Initialise Project ###
In the project root terminal type:
```shell
nicola init
```

### Run Application ###
In a terminal in the root directory, type:
```shell
nicola dashboard
```

This will start the application in a web browser at: http://127.0.0.1:8050/

## Amend Data ##
The project initialises with dummy data contained in `./data/attendance.xlsx`. You can amend this data to suit your needs.